@@ -1,7 +1,8 @@
-__all__ = ['Job', 'Message', 'Queue', 'Worker', '__version__']
+from pkg_resources import get_distribution
 
 from kq.job import Job
 from kq.message import Message
 from kq.queue import Queue
 from kq.worker import Worker
-from kq.version import __version__
+
+__version__ = get_distribution("kq").version
